% fig2.m  Run simulations and plot results for voltage
%         clamp step for the model of:
%
%            Bruce, I. C. (2009). "Evaluation of stochastic differential equation
%            approximation of ion channel gating models," Annals of Biomedical
%            Engineering 37(4):824838.
%
% Ian C. Bruce (ibruce@ieee.org)  2009

Na_max = 1e3;
K_max = 333;

trials = 1e3; % number of stimulus trials

Vh = 0;
Vcs = [48 24 16];

lps = length(Vcs);

hp = zeros(lps,2);

figure;


for lp = 1:lps

    Vc = Vcs(lp);
    
    [meanNa,stdNa,meanK,stdK,V,t]=VCstats('cw',Vh,Vc,trials,Na_max,K_max);

    subplot(3,2,(lp-1)*2+1)
    errorbar(t(1:50:end),meanNa(1:50:end),stdNa(1:50:end),'r','linestyle','none')
    hold on
    hp(lp,1) = plot(t,meanNa,'r');
    xlim([0 2])
    ylabel('N_{Na}(t)')
    
    subplot(3,2,(lp-1)*2+2)
    errorbar(t(1:50:end),meanK(1:50:end),stdK(1:50:end),'r','linestyle','none')
    hold on
    plot(t,meanK,'r')
    xlim([0 2])
    ylabel('N_{K}(t)')

    [meanNa,stdNa,meanK,stdK,V,t]=VCstats('fx',Vh,Vc,trials,Na_max,K_max);   
    
    subplot(3,2,(lp-1)*2+1)
    errorbar(t(1:50:end),meanNa(1:50:end),stdNa(1:50:end),'b','linestyle','none')
    hold on
    hp(lp,2) = plot(t,meanNa,'b');
    title(['V_c = ' num2str(Vc) ' mV'])

    subplot(3,2,(lp-1)*2+2)
    errorbar(t(1:50:end),meanK(1:50:end),stdK(1:50:end),'b','linestyle','none')
    hold on
    plot(t,meanK,'b')
    title(['V_c = ' num2str(Vc) ' mV'])
   
  
end

subplot(3,2,1)
legend(hp(1,:),'Chow & White','Fox & Lu')
subplot(3,2,5)
xlabel('t (ms)')
subplot(3,2,6)
xlabel('t (ms)')
