% fig8.m  Run simulations and plot results for Fig. 8 of:
%
%            Bruce, I. C. (2009). "Evaluation of stochastic differential equation
%            approximation of ion channel gating models," Annals of Biomedical
%            Engineering 37(4):824838.
%
% Ian C. Bruce (ibruce@ieee.org)  2009

nrep = 1e3;

Na_maxs = [100 500 1e3 5e3 1e4];   % Vector of numbers of sodium channels
nlps = length(Na_maxs);

figure

% Constant channel density case => scaled R & C

scaling = 'scaled';

Ith_cw = zeros(1,nlps);
Ith_fx = zeros(1,nlps);
RS_cw = zeros(1,nlps);
RS_fx = zeros(1,nlps);

for nlp=1:nlps

    Na_max = Na_maxs(nlp);

    disp(['Na_max = ' int2str(Na_max)])
    
    [Ith_cw(nlp),RS_cw(nlp),FEs_cw,Is_cw]=findIthRS('cw',[],nrep,Na_max,scaling);
    [Ith_fx(nlp),RS_fx(nlp),FEs_fx,Is_fx]=findIthRS('fx',[],nrep,Na_max,scaling);

end

subplot(2,2,1)
semilogx(Na_maxs,Ith_cw,'r*-')
hold on
semilogx(Na_maxs,Ith_fx,'bs-')
ylabel('I_{th} (pA)')
title('Constant channel density')

subplot(2,2,3)
h1=semilogx(Na_maxs,RS_cw,'r*-');
hold on
h2=semilogx(Na_maxs,RS_fx,'bs-');
ylabel('RS')
xlabel('N_{Na}^{max}')
legend([h1 h2],'Chow & White','Fox & Lu')


% Constant membrane area case => non-scaled R & C

scaling = 'notscaled';

Ith_cw = zeros(1,nlps);
Ith_fx = zeros(1,nlps);
RS_cw = zeros(1,nlps);
RS_fx = zeros(1,nlps);

for nlp=1:nlps

    Na_max = Na_maxs(nlp);

    disp(['Na_max = ' int2str(Na_max)])
    
    [Ith_cw(nlp),RS_cw(nlp),FEs_cw,Is_cw]=findIthRS('cw',[],nrep,Na_max,scaling);
    [Ith_fx(nlp),RS_fx(nlp),FEs_fx,Is_fx]=findIthRS('fx',[],nrep,Na_max,scaling);

end

subplot(2,2,2)
semilogx(Na_maxs,Ith_cw,'r*-')
hold on
semilogx(Na_maxs,Ith_fx,'bs-')
title('Constant membrane area')

subplot(2,2,4)
semilogx(Na_maxs,RS_cw,'r*-')
hold on
semilogx(Na_maxs,RS_fx,'bs-')
xlabel('N_{Na}^{max}')

