% fig9.m  Run simulations and plot results for Fig. 9 of:
%
%            Bruce, I. C. (2009). "Evaluation of stochastic differential equation
%            approximation of ion channel gating models," Annals of Biomedical
%            Engineering 37(4):824838.
%
% Ian C. Bruce (ibruce@ieee.org)  2009

nrep = 1e3;

Na_maxs = [100 500 1e3 5e3 1e4];   % Vector of numbers of sodium channels
nlps = length(Na_maxs);

scaling = 'scaled';

figure

% Single m-particle sodium channel model

RS_cw = zeros(1,nlps);
RS_fx = zeros(1,nlps);

for nlp=1:nlps

    Na_max = Na_maxs(nlp);

    disp(['Na_max = ' int2str(Na_max)])
    
    [Ith_cw,RS_cw(nlp),FEs_cw,Is_cw]=findIthRS('cwsm',[],nrep,Na_max,scaling);
    [Ith_fx,RS_fx(nlp),FEs_fx,Is_fx]=findIthRS('fxsm',[],nrep,Na_max,scaling);

end

subplot(2,1,1)
h1=semilogx(Na_maxs,RS_cw,'r*-');
hold on
h2=semilogx(Na_maxs,RS_fx,'bs-');
ylabel('RS')
title('Stochastic h particle')

% Single m-particle, deterministic h-particle sodium channel model

RS_cw = zeros(1,nlps);
RS_fx = zeros(1,nlps);

for nlp=1:nlps

    Na_max = Na_maxs(nlp);

    disp(['Na_max = ' int2str(Na_max)])
    
    [Ith_cw,RS_cw(nlp),FEs_cw,Is_cw]=findIthRS('cwsmdh',[],nrep,Na_max,scaling);
    [Ith_fx,RS_fx(nlp),FEs_fx,Is_fx]=findIthRS('fxsmdh',[],nrep,Na_max,scaling);

end

subplot(2,1,2)
semilogx(Na_maxs,RS_cw,'r*-')
hold on
semilogx(Na_maxs,RS_fx,'bs-')
ylabel('RS')
xlabel('N_{Na}^{max}')
title('Deterministic h particle')
